% test script: 14N-Nitroxide + Deuterium EDNMR spectra simulation
close all

MWFQ=94; % define microwave frequency in GHz

% Spin System that defines orientation selection - SysE
Sys.S=1/2;
Sys.g=[2.00905506 2.00617263 2.002270418];
Sys.Nucs='14N,2H';
A1=[4.2 4.2 34.1]*2.8;
A2=[-1 -1 2]/1.5;
Q1=[1.2 0.5 -1.7];
Q2=[.1 .1 -.2];
Sys.A=[A1;A2];
Sys.Q=[Q1;Q2];
Sys.lw = .3;
Sys.lwEndor=1.4;

% Calculate EPR spectrum for field position

ParE=struct('mwFreq',MWFQ,'nPoints',1024,'Harmonic',0);
OptE=struct('nKnots',21);
[f,Spe]=pepper(Sys,ParE,OptE); Spe=Spe/max(Spe);
figure(1);
plot(f,Spe,f,deriv(Spe)/max(deriv(Spe))); axis([min(f) max(f) -1 1.15]);
title(['EPR spectrum at ', num2str(MWFQ), ' GHz']); 
annotation('textbox',[.25 .8 .1 .1],'String','read out the field position for EDNMR simulation!')
xlabel('Magnetic Field /mT');
F=input('magnetic field for EDNMR simulation /mT = '); % ask for B0 value for EDNMR simulation


% Calculate ENDOR spectrum
Exp=struct('mwFreq',MWFQ,'Field',F,'Range',[0 200],'ExciteWidth',14,'nPoints',2048,'Harmonic',0);
Opt.Symmetry = 'D2h'; Opt.nKnots=91; Opt.Threshold=0.0001;
Opt.method='matrix';  
[x,y]=salt(Sys,Exp,Opt); 

% Define EDNMR parameters
Exp.Range = [-160 160];
Exp.w1=pi*10.2e6; % w1 in rad/s
Exp.T2=1e-6;      % decay time of ENDMR nutations in s
Exp.HTA=1000e-6;    % HTA pulse length in s
Exp.Q=700;        %Q0 of the cavity


% Calculate EDNMR spectrum
[x1,y1] =  EDNMR(Sys,Exp,Opt);


% Output results
figure(100)
plot(x1,y1/max(y1),x,y/max(y),'r')
title(['EDNMR and ENDOR spectra at ', num2str(F), ' mT & ', num2str(MWFQ), ' GHz']);
xlabel('Frequency /MHz');
str = {'Red Line - ENDOR (salt)', 'Blue line - EDNMR'};
annotation('textbox',[.15 .8 .1 .1],'String',str)
